@@ -1,7 +1,7 @@
 package Catmandu::Exporter::MAB2;
 
 #ABSTRACT: Package that exports MAB2 data
-our $VERSION = '0.03'; #VERSION
+our $VERSION = '0.04'; #VERSION
 
 use Catmandu::Sane;
 use MAB2::Writer::Disk;
@@ -73,7 +73,7 @@ Catmandu::Exporter::MAB2 - Package that exports MAB2 data
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -95,13 +95,49 @@ version 0.03
 
 Catmandu::Exporter::MAB2 - serialize parsed MAB2 data
 
+=head1 Arguments
+
+=over
+
+=item C<file>
+
+Path to file with MAB2 records.
+
+=item C<fh>
+
+Open filehandle for file with MAB2 records.
+
+=item C<type>
+
+Specify type of MAB2 records: Disk (Diskette), RAW (Band), XML. Default: 001. Optional. 
+
+=item C<xml_declaration>
+
+Write XML declaration. Set to 0 or 1. Default: 0. Optional.
+
+=item C<collection>
+
+Wrap records in collection element (<datei>). Set to 0 or 1. Default: 0. Optional.
+
+=back
+
 =head1 METHODS
 
-=head2 new(file => $file, %options)
+=head2 new(file => $file | fh => $filehandle [, type => XML, xml-declaration => 1, collection => 1])
 
-Create a new Catmandu MAB2 exports which serializes into a $file. Optionally
-provide xml_declaration => 0|1 to in/exclude a XML declaration and, collection => 0|1
-to include a MAB2 collection header.
+Create a new Catmandu MAB2 exports which serializes into a $file.
+
+=head2 add($data)
+
+Add record to exporter. 
+
+=head2 commit()
+
+Close collection (optional) and filehandle.
+
+=head1 SEE ALSO
+
+L<Catmandu::Exporter>, L<Catmandu::Iterable>.
 
 =head1 AUTHOR
 
