@@ -1,7 +1,7 @@
 package Catmandu::Fix::mab_map;
 
 # ABSTRACT: copy mab values of one field to a new field
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use Catmandu::Sane;
 use Catmandu::Util qw(:is :data);
@@ -191,7 +191,7 @@ Catmandu::Fix::mab_map - copy mab values of one field to a new field
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -226,6 +226,10 @@ version 0.03
 
 Catmandu::Fix::mab_map - copy mab values of one field to a new field
 
+=head1 SEE ALSO
+
+L<Catmandu::Fix>, L<Catmandu::Introduction>;
+
 =head1 AUTHOR
 
 Johann Rolschewski <rolschewski@gmail.com>
