@@ -1,7 +1,7 @@
 package MAB2::Parser::XML;
 
 # ABSTRACT: MAB2 XML parser
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use strict;
 use warnings;
@@ -9,8 +9,6 @@ use Carp qw<croak>;
 use XML::LibXML::Reader;
 
 
-# ToDo: use Moo
-
 sub new {
     my $class = shift;
     my $file  = shift;
@@ -104,7 +102,7 @@ MAB2::Parser::XML - MAB2 XML parser
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -121,21 +119,35 @@ filehande with a specified I/O layer.
         # do something        
     }
 
-=head1 SUBROUTINES/METHODS
+=head1 Arguments
 
-=head2 new
+=over
+
+=item C<file>
+
+Path to file with MAB2 XML records.
+
+=item C<fh>
+
+Open filehandle for file with MAB2 XML records.
+
+=back
+
+=head1 METHODS
+
+=head2 new($filename | $filehandle)
 
 =head2 next()
 
 Reads the next record from MAB2 XML input stream. Returns a Perl hash.
 
-=head2 _decode()
+=head2 _decode($record)
 
-Deserialize a MAB2 XML record to an array of field arrays.
+Deserialize a MAB2 XML record to an an ARRAY of ARRAYs.
 
 =head1 SEEALSO
 
-...
+L<Catmandu::Importer::MAB2>.
 
 =head1 AUTHOR
 
