@@ -1,28 +1,29 @@
 package MAB2::Writer::Disk;
 
 #ABSTRACT: MAB2 Diskette format serializer
-our $VERSION = '0.03'; #VERSION
+our $VERSION = '0.04'; #VERSION
 
 use strict;
-use Moo;
-with 'MAB2::Writer::Handle';
-
 use charnames ':full';
 use Readonly;
+use Moo;
 
-Readonly my $SUBFIELD_INDICATOR => qq{\N{INFORMATION SEPARATOR ONE}};
-Readonly my $END_OF_FIELD       => qq{\n};
-Readonly my $END_OF_RECORD      => qq{\n};
+with 'MAB2::Writer::Handle';
+
+has subfield_indicator => (
+    is  => 'rw',
+    default => sub { qq{\N{INFORMATION SEPARATOR ONE}} }
+);
 
 
-sub BUILD {
-    my ($self) = @_;
-}
+Readonly my $END_OF_FIELD       => qq{\N{LINE FEED}};
+Readonly my $END_OF_RECORD      => qq{\N{LINE FEED}};
 
 
 sub _write_record {
     my ( $self, $record ) = @_;
     my $fh = $self->fh;
+    my $SUBFIELD_INDICATOR = $self->subfield_indicator;
 
     if ( $record->[0][0] eq 'LDR' ) {
         my $leader = shift( @{$record} );
@@ -51,6 +52,7 @@ sub _write_record {
     print $fh $END_OF_RECORD;
 }
 
+
 1;
 
 __END__
@@ -63,7 +65,7 @@ MAB2::Writer::Disk - MAB2 Diskette format serializer
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -95,11 +97,27 @@ L<MAB2::Writer::Disk> is a MAB2 Diskette serializer.
         $writer->write($record);
     }
 
-=head1 SUBROUTINES/METHODS
+=head1 Arguments
 
-=head2 new()
+=over
 
-=head2 _write_record()
+=item C<subfield_indicator>
+
+Set subfield separator. Default: INFORMATION SEPARATOR ONE. Optional.
+
+=back
+
+See also L<MAB2::Writer::Handle>.
+
+=head1 METHODS
+
+=head2 new(file => $file | fh => $fh [, encoding => 'UTF-8', subfield_separator => '$'])
+
+=head2 _write_record($record)
+
+=head1 SEEALSO
+
+L<MAB2::Writer::Handle>, L<Catmandu::Exporter>.
 
 =head1 AUTHOR
 
